//
// C++ Interface: CPrefEdit
//
// Description: 
//
//
// Author: Harald Krippel <harald@the-develop.net>, (C) 2007
//
// Copyright: See COPYING file that comes with this distribution
//
//

#ifndef CPREFEDITDLG_H
#define CPREFEDITDLG_H

/**
  *@author Krippel Harald
  */

#include <QDialog>
#include <QString>
#include <QPixmap>

#include "ui_prefdlg4.h"
#include "CQcakeDlg.hpp"
#include "listviews.hpp"


class CPrefEditDlg: public CQcakeDlg
{
    Q_OBJECT
      
public:
    CPrefEditDlg(QString, QWidget * parent = 0, QString tmppath ="", int tmpfps=0, int tmpphfps=0,Qt::WFlags f = 0 );
    ~CPrefEditDlg();
    QString geteditpath();
    int getfps();
    int getphfps();

public slots:
    virtual void slotGetData();
    virtual void slotEditData();
    void slotGetEditor();
    void loadFromSettings();

private slots:
 
protected:
    Ui::PrefEditDlg ui;
    QString editorpath;
    int fps;
    int phfps;
    
private:
    QWidget *myParent;
};
#endif
